@@ -65,10 +65,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 # URL: http://tungwaiyip.info/software/HTMLTestRunner.html
 
 __author__ = "Wai Yip Tung,  Findyou，Adil, Javen"
-__version__ = "1.3"
+__version__ = "1.6"
 
 """
 Change History
+Version 1.6 -Javen
+* 支持实时测试进度
 
 Version 1.3 -Javen
 * 添加日志输出
@@ -714,10 +716,10 @@ class HTMLTestRunner(Template_mixin):
 
         self.startTime = datetime.datetime.now()
 
-    def run(self, test):
+    def run(self, test, django_db=None, caseTotal=None, sql=None):
         "Run the given test case or test suite."
         result = _TestResult(self.verbosity, self.trynum)
-        test(result)
+        test(result, django_db, caseTotal, sql)
         self.stopTime = datetime.datetime.now()
         self.generateReport(test, result)
         print('\nTime Elapsed: %s' % (self.stopTime - self.startTime), file=sys.stderr)
